<!DOCTYPE html>
<html lang="en">

<head>

    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="">
    <meta name="author" content="">

    <title>Blog</title>

    <!-- Bootstrap Core CSS -->
    <link href="https://buttercms.com/static/demoblog/css/bootstrap.min.css" rel="stylesheet">

    <!-- Custom CSS -->
    <link href="https://buttercms.com/static/demoblog/css/clean-blog.min.css" rel="stylesheet">

    <!-- Custom Fonts -->
    <link href="http://maxcdn.bootstrapcdn.com/font-awesome/4.1.0/css/font-awesome.min.css" rel="stylesheet" type="text/css">
    <link href='http://fonts.googleapis.com/css?family=Lora:400,700,400italic,700italic' rel='stylesheet' type='text/css'>
    <link href='http://fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800' rel='stylesheet' type='text/css'>

    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
        <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
        <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->

</head>

<body style="padding-top: 60px;">

    <!-- Navigation -->
    <nav class="navbar navbar-default navbar-custom" style="background-color: #404040;">
        <div class="container-fluid">
            <!-- Brand and toggle get grouped for better mobile display -->
            <div class="navbar-header page-scroll">
                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1">
                    <span class="sr-only">Toggle navigation</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <a class="navbar-brand" href="{% url 'blog' %}">Blog home</a>
            </div>


        </div>
        <!-- /.container -->
    </nav>



    <!-- Main Content -->
    <div class="container">
    {% block content %}
      <div class="row">
        <div class="col-lg-8 col-lg-offset-2 col-md-10 col-md-offset-1">

        {% for post in recent_posts %}
        <div class="post-preview">
            <a href="{% url 'blog_post' post.slug %}">
              <h2 class="post-title">
                  {{ post.title }}
              </h2>
            </a>
            <p class="post-meta">Posted by <a href="{% url 'blog_author' post.author.slug %}">{{ post.author.first_name }} {{ post.author.last_name }}</a> on {{ post.created }}</p>
            <p class="post-subtitle">{{ post.summary }}</p>
        </div>
        <hr>
        {% endfor %}

        <ul class="pager">
          {% if next_page %}
          <li class="previous">
            <a href="{% url 'archive' next_page %}">&larr; Older Posts</a>
          </li>
          {% endif %}

          {% if previous_page %}
          <li class="next">
            <a href="{% url 'archive' previous_page %}">Newer Posts &rarr;</a>
          </li>
          {% endif %}
        </ul>
        </div>
      </div>
      {% endblock %}
    </div>

    <hr>

    <!-- Footer -->
    <footer>
        <div class="container">
            <div class="row">
                <div class="col-lg-8 col-lg-offset-2 col-md-10 col-md-offset-1">
                    <ul class="list-inline text-center">
                        <li>
                            <a href="#">
                                <span class="fa-stack fa-lg">
                                    <i class="fa fa-circle fa-stack-2x"></i>
                                    <i class="fa fa-twitter fa-stack-1x fa-inverse"></i>
                                </span>
                            </a>
                        </li>
                        <li>
                            <a href="#">
                                <span class="fa-stack fa-lg">
                                    <i class="fa fa-circle fa-stack-2x"></i>
                                    <i class="fa fa-facebook fa-stack-1x fa-inverse"></i>
                                </span>
                            </a>
                        </li>
                        <li>
                            <a href="#">
                                <span class="fa-stack fa-lg">
                                    <i class="fa fa-circle fa-stack-2x"></i>
                                    <i class="fa fa-github fa-stack-1x fa-inverse"></i>
                                </span>
                            </a>
                        </li>
                    </ul>
                    <p class="copyright text-muted">Copyright &copy; Your Website 2015</p>
                </div>
            </div>
        </div>
    </footer>

    <!-- jQuery -->
    <script src="https://buttercms.com/static/demoblog/js/jquery.min.js"></script>

    <!-- Bootstrap Core JavaScript -->
    <script src="https://buttercms.com/static/demoblog/js/bootstrap.min.js"></script>

    <!-- Custom Theme JavaScript -->
    <script src="https://buttercms.com/static/demoblog/js/clean-blog.min.js"></script>

</body>

</html>
